@@ -34,7 +34,7 @@ func Run() (err error) {
 	app := cli.NewApp()
 	app.Name = "croc"
 	if Version == "" {
-		Version = "v9.1.4-d0ebb7a"
+		Version = "v9.1.5-0124356"
 	}
 	app.Version = Version
 	app.Compiled = time.Now()
@@ -116,8 +116,9 @@ func Run() (err error) {
 				_, basename := filepath.Split(fpath)
 				fnames = append(fnames, "'"+basename+"'")
 			}
-			yn := utils.GetInput(fmt.Sprintf("Did you mean to send %s? (y/n) ", strings.Join(fnames, ", ")))
-			if strings.ToLower(yn) == "y" {
+			promptMessage := fmt.Sprintf("Did you mean to send %s? (Y/n) ", strings.Join(fnames, ", "))
+			choice := strings.ToLower(utils.GetInput(promptMessage))
+			if choice == "" || choice == "y" || choice == "yes" {
 				return send(c)
 			}
 		}
@@ -229,6 +230,18 @@ func send(c *cli.Context) (err error) {
 		if !c.IsSet("pass") {
 			crocOptions.RelayPassword = rememberedOptions.RelayPassword
 		}
+		if !c.IsSet("relay6") {
+			crocOptions.RelayAddress6 = rememberedOptions.RelayAddress6
+		}
+		if !c.IsSet("overwrite") {
+			crocOptions.Overwrite = rememberedOptions.Overwrite
+		}
+		if !c.IsSet("curve") {
+			crocOptions.Curve = rememberedOptions.Curve
+		}
+		if !c.IsSet("local") {
+			crocOptions.OnlyLocal = rememberedOptions.OnlyLocal
+		}
 	}
 
 	var fnames []string
@@ -323,7 +336,6 @@ func makeTempFileWithString(s string) (fnames []string, err error) {
 	}
 	fnames = []string{f.Name()}
 	return
-
 }
 
 func getPaths(fnames []string) (paths []string, haveFolder bool, err error) {
@@ -443,6 +455,18 @@ func receive(c *cli.Context) (err error) {
 		if !c.IsSet("pass") {
 			crocOptions.RelayPassword = rememberedOptions.RelayPassword
 		}
+		if !c.IsSet("relay6") {
+			crocOptions.RelayAddress6 = rememberedOptions.RelayAddress6
+		}
+		if !c.IsSet("overwrite") {
+			crocOptions.Overwrite = rememberedOptions.Overwrite
+		}
+		if !c.IsSet("curve") {
+			crocOptions.Curve = rememberedOptions.Curve
+		}
+		if !c.IsSet("local") {
+			crocOptions.OnlyLocal = rememberedOptions.OnlyLocal
+		}
 	}
 
 	if crocOptions.SharedSecret == "" {
